==> mingw-w64-python-polars-1.35.2-1.src.tar.zst: polars-py-1.35.2/docs/source/src/rust/user-guide/expressions/lists.rs <==
fn main() -> Result<(), Box<dyn std::error::Error>> {
    // --8<-- [start:list-example]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:list-example]

    // --8<-- [start:array-example]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:array-example]

    // --8<-- [start:numpy-array-inference]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:numpy-array-inference]

    // --8<-- [start:weather]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:weather]

    // --8<-- [start:split]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:split]

    // --8<-- [start:explode]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:explode]

    // --8<-- [start:list-slicing]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:list-slicing]

    // --8<-- [start:element-wise-casting]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:element-wise-casting]

    // --8<-- [start:element-wise-regex]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:element-wise-regex]

    // --8<-- [start:weather_by_day]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:weather_by_day]

    // --8<-- [start:rank_pct]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:rank_pct]

    // --8<-- [start:array-overview]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:array-overview]

    Ok(())
}

==> mingw-w64-python-polars-1.37.1-2.src.tar.zst: polars-py-1.37.1/docs/source/src/rust/user-guide/expressions/lists.rs <==
fn main() -> Result<(), Box<dyn std::error::Error>> {
    // --8<-- [start:list-example]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:list-example]

    // --8<-- [start:array-example]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:array-example]

    // --8<-- [start:numpy-array-inference]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:numpy-array-inference]

    // --8<-- [start:weather]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:weather]

    // --8<-- [start:split]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:split]

    // --8<-- [start:explode]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:explode]

    // --8<-- [start:list-slicing]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:list-slicing]

    // --8<-- [start:element-wise-casting]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:element-wise-casting]

    // --8<-- [start:element-wise-regex]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:element-wise-regex]

    // --8<-- [start:children]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:children]

    // --8<-- [start:list-sorting]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:list-sorting]

    // --8<-- [start:list-aggregation]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:list-aggregation]

    // --8<-- [start:list-entropy]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:list-entropy]

    // --8<-- [start:weather_by_day]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:weather_by_day]

    // --8<-- [start:rank_pct]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:rank_pct]

    // --8<-- [start:array-overview]
    // Contribute the Rust translation of the Python example by opening a PR.
    // --8<-- [end:array-overview]

    Ok(())
}
